==> deepin-calculator_6.5.4.tar.xz: BUILD/translations/deepin-calculator_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Erro de expressão</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Limpar toda a memória</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Limpar histórico</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Selecionar Tudo</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Científico</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>A Calculadora é uma ferramenta de cálculo, fácil de usar e compatível com os modos científico e programador.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Programador</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Limpar item da memória</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Limpar toda a memória</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Recuperar memória</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Adicionar item à memória</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Adicionar memória</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Subtrair item da memória</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Subtrair memória</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Gravar na memória</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Limpar item da memória</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Adicionar item à memória</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Subtrair item da memória</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>Nada gravado na memória</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Erro de expressão</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Deslocamento aritmético</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Deslocamento lógico</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Deslocamento circular</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Girar através do deslocamento circular de transporte</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Deslocamento aritmético</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Deslocamento lógico</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Deslocamento circular</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Girar através do deslocamento circular de transporte</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Erro de expressão</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Erro de expressão</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>Nenhum histórico</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
</context>
</TS>

==> deepin-calculator_6.5.9.tar.xz: BUILD/translations/deepin-calculator_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Erro de expressão</translation>
    </message>
</context>
<context>
    <name>IconButton</name>
    <message>
        <source>Clear all memory</source>
        <translation>Limpar toda a memória</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation>Limpar histórico</translation>
    </message>
</context>
<context>
    <name>InputEdit</name>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Selecionar tudo</translation>
    </message>
    <message>
        <source>Use thousands separator</source>
        <translation>Use o separador de milhar</translation>
    </message>
    <message>
        <source>Use ten-thousands separator</source>
        <translation>Use o separador de dez mil</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Desfazer</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Refazer</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Recortar</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Colar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
    <message>
        <source>Standard</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>Scientific</source>
        <translation>Científico</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <source>Calculator is an easy to use desktop calculator, supporting standard, scientific and programmer modes.</source>
        <translation>A Calculadora é uma ferramenta de fácil utilização, com suporte aos modos padrão, científico e programador.</translation>
    </message>
    <message>
        <source>Programmer</source>
        <translation>Programador</translation>
    </message>
</context>
<context>
    <name>MemoryButton</name>
    <message>
        <source>Clear memory item</source>
        <translation>Limpar item da memória</translation>
    </message>
    <message>
        <source>Clear all memory</source>
        <translation>Limpar toda a memória</translation>
    </message>
    <message>
        <source>Memory recall</source>
        <translation>Recuperar memória</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Adicionar item à memória</translation>
    </message>
    <message>
        <source>Memory add</source>
        <translation>Adicionar à memória</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Remover item da memória</translation>
    </message>
    <message>
        <source>Memory subtract</source>
        <translation>Remover da memória</translation>
    </message>
    <message>
        <source>Memory store</source>
        <translation>Armazenar na memória</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
</context>
<context>
    <name>MemoryItemWidget</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Clear memory item</source>
        <translation>Limpar item da memória</translation>
    </message>
    <message>
        <source>Add to memory item</source>
        <translation>Adicionar item à memória</translation>
    </message>
    <message>
        <source>Subtract from memory item</source>
        <translation>Remover item da memória</translation>
    </message>
</context>
<context>
    <name>MemoryWidget</name>
    <message>
        <source>Nothing saved in memory</source>
        <translation>Não há nada salvo na memória</translation>
    </message>
</context>
<context>
    <name>ProExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Erro de expressão</translation>
    </message>
</context>
<context>
    <name>ProListView</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
<context>
    <name>ProgramModule</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Deslocamento aritmético</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Deslocamento lógico</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Deslocamento circular</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Girar através do deslocamento circular de transporte</translation>
    </message>
</context>
<context>
    <name>ProgrammerItemWidget</name>
    <message>
        <source>Arithmetic shift</source>
        <translation>Deslocamento aritmético</translation>
    </message>
    <message>
        <source>Logical shift</source>
        <translation>Deslocamento lógico</translation>
    </message>
    <message>
        <source>Circular shift</source>
        <translation>Deslocamento circular</translation>
    </message>
    <message>
        <source>Rotate through carry circular shift</source>
        <translation>Girar através do deslocamento circular de transporte</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Calculator</source>
        <translation>Calculadora</translation>
    </message>
</context>
<context>
    <name>SciExpressionBar</name>
    <message>
        <source>Expression error</source>
        <translation>Erro de expressão</translation>
    </message>
</context>
<context>
    <name>SciHistoryWidget</name>
    <message>
        <source>History</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression error</source>
        <translation>Erro de expressão</translation>
    </message>
</context>
<context>
    <name>SimpleListModel</name>
    <message>
        <source>No history</source>
        <translation>Não há histórico</translation>
    </message>
</context>
<context>
    <name>SimpleListView</name>
    <message>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Excluir</translation>
    </message>
</context>
</TS>
